Struct init_once::PollInit

source ·
pub struct PollInit<'a, T> { /* private fields */ }
Polling mechanism to initialize a value contained in some InitOnce instance.

Implementations

source

impl<'init_once, T> PollInit<'init_once, T>

source

pub async fn init_async<F>(&self, init: F) -> &'init_once T
where F: Future<Output = T>,

Initialize the associated InitOnce with the given future init.

source

pub fn poll_init<F>(&self, init: F) -> Poll<&'init_once T>
where F: FnMut() -> Poll<T>,

Check if the value returned by init is ready.

While it is technically possible to initialize multiple different values with this method, the InitOnce abstraction’s soundness is not affected.